@@ -10,8 +10,6 @@ from tempfile import NamedTemporaryFile, TemporaryDirectory
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Sequence, Union, cast
 from zipfile import ZipFile
 
-from pip._internal.req.constructors import install_req_from_line
-
 from cognite.client import utils
 from cognite.client._api_client import APIClient
 from cognite.client._constants import LIST_LIMIT_CEILING, LIST_LIMIT_DEFAULT
@@ -718,6 +716,8 @@ def _validate_and_parse_requirements(requirements: List[str]) -> List[str]:
     Returns:
         List[str]: The parsed requirements
     """
+    constructors = cast(Any, utils._auxiliary.local_import("pip._internal.req.constructors"))
+    install_req_from_line = constructors.install_req_from_line
     parsed_reqs: List[str] = []
     for req in requirements:
         try:
